#
# spec file for package ghc-blaze-html
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name blaze-html
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.2.0
Release:        2.6
Summary:        A blazingly fast HTML combinator library for Haskell
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-blaze-builder-prof
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-blaze-markup-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
%endif

%description
A blazingly fast HTML combinator library for the Haskell programming language.
The Text.Blaze module is a good starting point, as well as this tutorial:
<http://jaspervdj.be/blaze/tutorial.html>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jul  4 2024 Peter Simons <psimons@suse.com>
- Update blaze-html to version 0.9.2.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Mar  6 2024 Peter Simons <psimons@suse.com>
- Update blaze-html to version 0.9.2.0.
  - 0.9.2.0 (2024-03-06)
  * Make XHTML5 doctype lowercase
  * Add new attributes to (X)HTML5:
  - `download`
  - `minlength`
  - `muted`
  - `onkeypress`
  - `poster`
  - `property`
  * Add new elements to (X)HTML5:
  - `bdi`
  - `data`
  - `dialog`
  - `picture`
  - `s`
  - `search`
  - `slot`
  - `template`
* Thu Aug 31 2023 Peter Simons <psimons@suse.com>
- Update blaze-html to version 0.9.1.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jul 17 2023 Peter Simons <psimons@suse.com>
- Update blaze-html to version 0.9.1.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Feb  9 2022 Peter Simons <psimons@suse.com>
- Update blaze-html to version 0.9.1.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Mar  9 2021 psimons@suse.com
- Update blaze-html to version 0.9.1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct  3 2019 psimons@suse.com
- Update blaze-html to version 0.9.1.2.
  - 0.9.1.2 (2019-10-02)
  * Bump QuickCheck dependency to 2.13
  * Bump containers dependency to 0.6
  * Check in generated code
  * Regenerate .travis.yml using haskell-ci
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update blaze-html to version 0.9.1.1.
  - 0.9.1.1 (2018-06-12)
  * Fix generated source code on Hackage
  - 0.9.1.0
  * Add `u` element to HTML5
  * Add `role` attribute to HTML5
  * Bump HUnit dependency to 1.6
  * Bump QuickCheck dependency to 2.11
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.9.0.1.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.8.1.3 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.8.1.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.1.1 revision 0 with cabal2obs.
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 0.8.1.1
  * Bump HUnit dependency to 1.3
* Tue Aug  4 2015 mimi.vx@gmail.com
- update to 0.8.1.0
  * Add `<main>` element to HTML5
* Mon Apr 20 2015 mimi.vx@gmail.com
- update to 0.8.0.2
  * Relax blaze-builder dependency to include 0.3 again
  * Add `itemscope` and `itemprop` attributes
* Sun Nov  9 2014 peter.trommler@ohm-hochschule.de
- update to 0.7.0.3
  * version bound for text (Haskell Platform 2014.2.0.0)
  * compatibility with ghc-blaze-markup
* Mon Oct 21 2013 sbahling@suse.com
- spec file: Add %%defattr(-,root,root,-) to %%files devel section
* Wed May 15 2013 peter.trommler@ohm-hochschule.de
- update to 0.6.1.1 from upstream (no changelog)
  * base, keygen, and source elements are considered leaf elements
  * dependencies for test framework adjusted
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.1.0 from upstream (no changelog)
* Wed Jul  4 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.0.0 from upstream (no changelog)
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 template for spec file
- required for ghc-rpm-macros 0.90
* Fri Mar 16 2012 peter.trommler@ohm-hochschule.de
- added BuildRoof fo SLE_11_SP1/2
* Fri Mar  2 2012 peter.trommler@ohm-hochschule.de
- initial packaging
